	page	,132
	title	KAT - GENERAL KAT INTERFACE

;***********************************************************************
;
;	KAT - General KAT Interface
;
;	  This subroutine provides a general interface to KAT.	It accepts
;	four word parameters corresponding to the four input/outputs of KAT.
;
;	This routine also checks for the existence of someting at the KAT
;	interrupt (33h) before performing the interrupt to avoid crashing
;	the computer.  However, you must determine if the KAT is
;	installed or if something else is using the interrupt.	The Reset
;	function will aid in this.  If you receive a 0 value from Reset
;	then this subroutine didn't perform the interrupt (Reset always
;	returns -1 status.)  Note other KAT functions do return 0 in ax
;
;	This routine also automatically sets ES to DS for function 9 and
;	function 12.  To use these functions be sure that the offsets
;	passed are relative to DS.
;
;	This routine is intended to be called from other assemebly language
;	routines.  To use this routine with high-level languages, you must
;	add appropriate modifications for the calling sequence of the language.
;
;	ENTRY	 Kat, values in registers ax, bx, cx, dx
;
;	EXIT	 function returns
;		    if int 33h vector contains 0, no call made, ax = 0
;		    otherwise ax, bx, cx, dx contain values from KAT call
;
;	MODIFICATIONS
;		 C Chell   29-Apr-85  created
;			   22-Jul-85  recoded in asm
;
;	(C) COPYRIGHT 1985, Koala Technologies Corporation
;
;***********************************************************************


pgroup	group	prog
prog	segment byte public 'prog'
	assume	cs:pgroup
	public	Kat

callsok db	0			;flag for verifying int vector

Kat	proc	near
	push	es

;  Check flag to see if we have examined the interrupt vector yet
;  CS relative to avoid assumptions about DS
	cmp	cs:callsok,0		;ok to make calls?
	jne	kat2			;branch if yes

;  Check out the interrupt vector to see if it contains a non-zero address
;  DOS 2.0 initializes it to 0, DOS 3.0 inits to a IRET so this function
;  can only help avoid a system crash (jmp to 0).  Be sure to call KAT
;  function 0 to verify KAT installation.
	push	ax
	xor	ax,ax			;check out int 33h vector
	mov	es,ax
	pop	ax
	cmp	word ptr es:[0CCh],0	;KAT offset will never be 0
	jne	kat1			;since vector is 0, exit with 0
	xor	ax,ax			;return 0 status, no call made
	jmp	short kat9
kat1:	mov	cs:callosk,1		;vector nonzero, don't test it again

;  Call the KAT
kat2:	push	ds			;set es
	pop	es
	int	33h			;call KAT

;  Return with es unchanged
kat9:	pop	es
	ret

Kat	endp
prog	ends
	end
